OC.L10N.register(
    "federatedfilesharing",
    {
    "Accept" : "Прифати",
    "Decline" : "Одбиј",
    "Federated Cloud Sharing" : "Федерирано клауд споделување",
    "Open documentation" : "Отвори ја документацијата",
    "Federated Cloud" : "Федериран клауд",
    "Your Federated Cloud ID:" : "Вашиот федериран Cloud ID:",
    "Share it:" : "Сподели го:",
    "Add to your website" : "Додади на твојот веб сајт",
    "Share with me via ownCloud" : "Сподели со мене преку ownCloud",
    "HTML Code:" : "HTML код:",
    "Add to your ownCloud" : "Додади во вашиот ownCloud"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
